"""
CLI Program to turn reddit submissions and comments into Ebooks

 Usage: reddit2ebook initfile directory

 The initfile should be in the following format:

 bookname:
     - url
     - url
     - url

"""
